#
# spec file for package health-check
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           health-check
Version:        0.03.09
Release:        1.14
Summary:        Process monitoring tool
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://kernel.ubuntu.com/~cking/health-check
Source:         https://kernel.ubuntu.com/~cking/tarballs/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libbsd)

%description
Health-check monitors processes and optionally their child
processes and threads for a given amount of time.  At the end
of the monitoring it will display the CPU time used, wakeup
events generated and I/O operations of the given processes.
It can be used to diagnose unhealthy bad processes.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Benchmark
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (health-check and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install

%files
%license COPYING
%{_bindir}/health-check
%{_mandir}/man8/health-check.8%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Tue Aug  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.09:
  * net: don't throw warning messages when /proc file can't be
    opened
* Fri Apr 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.07
  * net.c: move declaration of send_total recv_total fix build
    failure
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Mar  8 2020 Martin Hauke <mardnh@gmx.de>
- Drop SLE12 compat ifdef
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.06
  * Add bash completion script
* Mon Jan 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.05
  * pid: sanity check for null return from basename call
* Tue Dec 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.04
  * syscall: handle a null return from localtime
  * set *inode to zero to clear up a static analysis false warning
  * ignore return from proc_pids_add_proc
  * net: pass size of link string in net_get_inode_by_path
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.03
  * No functional changes
* Fri Jun 14 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.03.01
  * Use safer strlcpy instead of strncpy
  * Remove events.h and references to timer stats
  * Fix buffer truncation warnings from gcc-9
  * Specify trusty in travis file
  * Add older package name for json c
- Add BuildRequires: pkgconfig(libbsd)
- Use https for Source and URL
* Sun Jun 17 2018 mardnh@gmx.de
- Update to version 0.03.00
  * Makefile: bump version to 3.0
  * debian/copyright: use secure URI
  * debian/compat: update to 11
  * debian/control: set debhelper version to >=11
  * debian/control: remove empty last line
  * remove event metrics since newer kernels don't support this API
* Fri Jan  5 2018 mardnh@gmx.de
- update to version 0.02.09
  * Makefile: bump version
  * debian/control: update Standards-Version to 4.1.2
  * health-check: unconstify metadata to clean up build warning
  * syscall: remove extraneous pid_size declaration
  * fnotify: fix build warning, include <sys/sysmacros.h>
  * Update copyright year
* Fri Oct 20 2017 mardnh@gmx.de
- update to version 0.02.08
  * Update to Standards-Version: 4.1.1
* Wed May 10 2017 mardnh@gmx.de
- update to version 0.02.06
  * Makefile: bump version
  * Manual: update copyright year and manual date
  * Add variable pid size handling.
  * syscall: cast pid to unsigned long to ensure hash does not overflow
  * Remove duplicate check on fnotify_files.head
- update to version 0.02.05
  * Makefile: bump version
  * Makefile: line break on OBJS line
  * voidify returns from close, fclose, closedir, etc
  * Update copyright year
  * Remove alloc shim for debugging heap.
  * syscall: fix inconsistent indenting
- update to version 0.02.04
  * Makefile: bump version
  * json: fix comment
  * syscall: fix shadowing warnings
  * Move procs_traced declaration to after the header includes
  * syscall: fix shadowing of string tmp
  * Makefile: remove status.[cho], it's not required as yet
  * fnotify: fix some shadowing on link pointer l
  * fnotify: make helper function static
  * fnotify: add some constifications
  * event: use floating point FLOAT_CMP macro for zero compare
  * event: add some more constifications
  * cpustat: use floating point FLOAT_CMP macro for zero compare
  * cpustat: add some constifications
  * health-check.h: add math.h
  * health-check: make helper function static
  * syscall: use FLOAT_CMP for float compare != 0
  * syscall: make helper functions static
  * ctxt-switch: use FLOAT_CMP to compare float against zero
  * ctxt-switch: add some constifications
  * mem: use FLOAT_CMP for float comparison to zero
  * mem: add some constifications
  * syscall: use floating point FLOAT_CMP macro for zero compare
  * syscall: more constifications
  * syscall constify pointers
  * compare floating point values with a little bit of slop
  * Makefile: add PEDANTIC flags
- update to version 0.02.03
  * Makefile: bump version
  * Debian/control: update Standards-Version to 3.9.8
  * Use strtok instead of strtok_r
* Thu Feb 18 2016 mardnh@gmx.de
- update to version 0.02.02
- upstream does not provide a changelog
* Wed Nov 11 2015 mardnh@gmx.de
- initial package
